@@ -12,6 +12,7 @@ from .logger import logger
 
 class Controllers():
 
+    FIELD_RE = re.compile('<([-a-z()_]+)$')
     PARAM_RE = re.compile(':([-a-z()_]+)$')
 
     def __init__(self, connection_string, max_rows, debug):
@@ -77,14 +78,20 @@ class Controllers():
         _headers = []
         _formatters = []
         for h in formatters:
+            field = self.FIELD_RE.findall(h)
+            if len(field) == 1:
+                field = field[0]
+                h = h[:-(len(field)+1)]
+            else:
+                field = None
             matches = self.PARAM_RE.findall(h)
-            funcs = []
+            funcs = [self.formatter('')]
             while len(matches) > 0:
                 mod = matches[0]
                 h = h[:-(len(mod)+1)]
                 funcs.append(self.formatter(mod))
                 matches = self.PARAM_RE.findall(h)
-            f = self.getter(h)
+            f = self.getter(field or h)
             for g in reversed(funcs):
                 f = self.compose(f, g)
             k = self.wrapper(f)
@@ -112,7 +119,7 @@ class Controllers():
     def formatter(self, mod):
         if mod == 'number':
             def _f(x, row):
-                return str(x)
+                return str(x) if x else ''
             return _f
         elif mod == 'yesno':
             def _f(x, row):
@@ -122,10 +129,11 @@ class Controllers():
             def _f(x, row):
                 if x and isinstance(x, list):
                     return ','.join(x)
+                return x
             return _f
         else:
             def _f(x, row):
-                return str(x)
+                return str(x) if x else ''
             return _f
 
     def jsonable(self, obj):
